oat_graphATestsForSampleSize_overTime <-
function(FILEPATH,PARAMETERS,PMIN,PMAX,PINC,ATESTRESULTSFILENAME,MEASURES,ATESTSIGLEVEL,TIMEPOINTS,TIMEPOINTSCALE)
{
	# LOOK AT EACH TIMEPOINT FOR THIS PARAMETER
	for(n in 1:length(TIMEPOINTS))
	{
		TIMEPOINTANALYSED<-TIMEPOINTS[n]
		print(paste("Time Point Analysed: ",TIMEPOINTANALYSED,sep=""))

		ATESTSFILENAME <- paste(ATESTRESULTSFILENAME,"_",TIMEPOINTANALYSED,sep="")
		
		oat_graphATestsForSampleSize(FILEPATH,PARAMETERS,PMIN,PMAX,PINC,MEASURES,ATESTSIGLEVEL,ATESTSFILENAME,TIMEPOINTANALYSED,TIMEPOINTSCALE)
	}
}

